@@ -1,7 +1,7 @@
 from protmo.pm import *
 from protmo.ast import *
 from protmo.utils import *
-
+from protmo.settings_loader import settings
 
 class _PythonToDart:
 
@@ -227,10 +227,10 @@ class BidirectionalStreamingMethod:
 
 
 def create_dart_file(package: str):
-    content = '''import 'package:dart_example/auth.dart';
-import 'package:dart_example/client.dart';
-import 'package:dart_example/proto/protmo.pbgrpc.dart';
+    content = '''import 'auth.dart';
+import 'client.dart';
 import 'package:grpc/grpc.dart';
+import 'models.pbgrpc.dart';
 
 '''
     messages: list[MessageInfo] = []
@@ -253,5 +253,5 @@ import 'package:grpc/grpc.dart';
     # registerClient(EmployeeMethodsClient(channel, interceptors: [AuthInterceptor(token)]));
     # }
 
-    with open('dart/lib/proto/rpc_methods.dart', 'w') as f:
+    with open(settings.DART_RPC_METHODS_FILE, 'w') as f:
         f.write(content)
